@@ -640,7 +640,6 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
         } else {
                 GMainLoop *loop = main_loops;
                 g_main_loop_quit(loop);
-		g_object_unref (loop);
 		gtk_main_quit();
         }
 	/* gst_element_send_event(data, gst_event_new_eos()); */
@@ -696,7 +695,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 1.1.1", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 1.2.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Voicegram", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -720,7 +719,7 @@ main (gint argc, gchar **argv)
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 1.1.1");
+	context = g_option_context_new ("- Voice 1.2.0");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -733,10 +732,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.1.1");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.2.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 1.1.1!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 1.2.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Voicegram:"));
 	title_entry = gtk_entry_new();
@@ -749,7 +748,7 @@ main (gint argc, gchar **argv)
 	page[2].widget = gtk_box_new(FALSE, 5);
 	filename_label = gtk_label_new(_("Filename:"));
 	filename_entry = gtk_entry_new();
-	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat (g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", "GNOME.ogg", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
+	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat ("GNOME.ogg", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_entry),
@@ -814,7 +813,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 1.1.1",
+				 GST_TAG_COMMENT, "Voice 1.2.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
